@@ -2,7 +2,7 @@ package Module::CPANTS::Kwalitee::CpantsErrors;
 use warnings;
 use strict;
 
-our $VERSION = '0.89';
+our $VERSION = '0.90_02'; $VERSION = eval $VERSION;
 
 sub order { 1000 }
 
@@ -24,7 +24,9 @@ sub analyse {
     my @eout=$sout->read;
     my @eerr=$serr->read;
     
-    $me->d->{error}{cpants}= (@eerr || @eout) ? join("\n",'STDERR:',@eerr,'STDOUT:',@eout) : '';
+    if (@eerr || @eout) {
+        $me->d->{error}{cpants}=join("\n",'STDERR:',@eerr,'STDOUT:',@eout);
+    }
 }
 
 
@@ -33,14 +35,25 @@ sub analyse {
 ##################################################################
 
 sub kwalitee_indicators {
-    return [
-        {
-            name=>'no_cpants_errors',
-            error=>q{Some errors occured during CPANTS testing. They might be caused by bugs in CPANTS or some strange features of this distribution. See 'cpants' in the dist error view for more info.},
-            remedy=>q{Please report the error(s) to bug-module-cpants-analyse@rt.cpan.org},
-            code=>sub { shift->{error}{cpants} ? 0 : 1 },
-        },
-    ];
+    # NOTE: CPANTS error should be logged somewhere, but it
+    # should not annoy people. If anything wrong or interesting
+    # is found in the log, add some metrics (if it's worth),
+    # or just fix our problems.
+
+    # Older Test::Kwalitee (prior to 1.08) has hardcoded metrics
+    # names in it, and if those metrics are gone from
+    # Module::CPANTS::Kwalitee, it fails because the number of tests
+    # is not as expected. This is not beautiful, but better than
+    # to break others' distributions needlessly.
+    if ($INC{"Test/Kwalitee.pm"}) {
+        return [
+            map {+{name => $_, code => sub {1}}}
+            qw/extractable no_pod_errors
+               has_test_pod has_test_pod_coverage/
+        ] if $Test::Kwalitee::VERSION < 1.08;
+    }
+
+    return [];
 }
 
 
@@ -52,11 +65,11 @@ __END__
 
 =head1 NAME
 
-Module::CPANTS::Kwalitee::CpantsErrors
+Module::CPANTS::Kwalitee::CpantsErrors - Check for CPANTS testing errors
 
 =head1 SYNOPSIS
 
-Checks if something strange happend during testing
+Checks if something strange happened during testing
 
 =head1 DESCRIPTION
 
